summaryrefslogtreecommitdiffstats
path: root/kate/plugins/wordcompletion
diff options
context:
space:
mode:
Diffstat (limited to 'kate/plugins/wordcompletion')
-rw-r--r--kate/plugins/wordcompletion/docwordcompletion.cpp12
-rw-r--r--kate/plugins/wordcompletion/docwordcompletion.h4
-rw-r--r--kate/plugins/wordcompletion/ktexteditor_docwordcompletion.desktop2
3 files changed, 9 insertions, 9 deletions
diff --git a/kate/plugins/wordcompletion/docwordcompletion.h b/kate/plugins/wordcompletion/docwordcompletion.h
index cb7349da5..ed632631a 100644
--- a/kate/plugins/wordcompletion/docwordcompletion.h
+++ b/kate/plugins/wordcompletion/docwordcompletion.h
@@ -106,7 +106,7 @@ class DocWordCompletionPluginView
TQString word();
TQValueList<KTextEditor::CompletionEntry> allMatches( const TQString &word );
- TQString tqfindLongestUnique(const TQValueList < KTextEditor::CompletionEntry > &matches);
+ TQString findLongestUnique(const TQValueList < KTextEditor::CompletionEntry > &matches);
KTextEditor::View *m_view;
struct DocWordCompletionPluginViewPrivate *d;
};
@@ -130,4 +130,4 @@ class DocWordCompletionConfigPage : public KTextEditor::ConfigPage
};
#endif // _DocWordCompletionPlugin_h_
-// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
diff --git a/kate/plugins/wordcompletion/ktexteditor_docwordcompletion.desktop b/kate/plugins/wordcompletion/ktexteditor_docwordcompletion.desktop
index 5941a1957..dd2a5e8dc 100644
--- a/kate/plugins/wordcompletion/ktexteditor_docwordcompletion.desktop
+++ b/kate/plugins/wordcompletion/ktexteditor_docwordcompletion.desktop
@@ -117,7 +117,7 @@ Comment[pt_BR]=Complementação direcional, ou baseada em popup, de palavras do
Comment[ro]=Propune completarea cuvintelor din document dintr-o listă popup sau direcţională
Comment[ru]=Автодополнение слов в документе
Comment[rw]=Irangiza mfatacyerekezo cyangwa rishingiye-kwirambura biva ku magambo yo mu nyandiko
-Comment[sk]=Dopĺňanie slov v dokumente priame alebo potqmocou dialógu
+Comment[sk]=Dopĺňanie slov v dokumente priame alebo pomocou dialógu
Comment[sl]=Neposredno ali pojavno dopolnjevanje iz besed v dokumentu
Comment[sr]=Директна или искачућа допуна од речи у документу
Comment[sr@Latn]=Direktna ili iskačuća dopuna od reči u dokumentu
diff --git a/kate/plugins/wordcompletion/docwordcompletion.cpp b/kate/plugins/wordcompletion/docwordcompletion.cpp
index 7bd0e83e0..37da55224 100644
--- a/kate/plugins/wordcompletion/docwordcompletion.cpp
+++ b/kate/plugins/wordcompletion/docwordcompletion.cpp
@@ -232,7 +232,7 @@ void DocWordCompletionPluginView::shellComplete()
{
// setup
KTextEditor::EditInterface * ei = KTextEditor::editInterface(m_view->document());
// tqfind the word we are typing
uint cline, ccol;
viewCursorInterface(m_view)->cursorPositionReal(&cline, &ccol);
TQString wrd = word();
@@ -242,7 +242,7 @@ void DocWordCompletionPluginView::shellComplete()
TQValueList < KTextEditor::CompletionEntry > matches = allMatches(wrd);
if (matches.size() == 0)
return;
- TQString partial = tqfindLongestUnique(matches);
+ TQString partial = findLongestUnique(matches);
if (partial.length() == wrd.length())
{
KTextEditor::CodeCompletionInterface * cci = codeCompletionInterface(m_view);
@@ -261,7 +261,7 @@ void DocWordCompletionPluginView::complete( bool fw )
{
// setup
KTextEditor::EditInterface *ei = KTextEditor::editInterface( m_view->document() );
// tqfind the word we are typing
uint cline, ccol;
viewCursorInterface( m_view )->cursorPositionReal( &cline, &ccol );
TQString wrd = word();
@@ -333,7 +333,7 @@ void DocWordCompletionPluginView::complete( bool fw )
TQString m = d->re.cap( 1 );
if ( m != d->lastIns )
{
- // we got good a match! tqreplace text and return.
+ // we got good a match! replace text and return.
if ( d->lilen )
ei->removeText( d->cline, d->ccol, d->cline, d->ccol + d->lilen );
ei->insertText( d->cline, d->ccol, m );
@@ -393,7 +393,7 @@ void DocWordCompletionPluginView::complete( bool fw )
}
// Contributed by <brain@hdsnet.hu>
-TQString DocWordCompletionPluginView::tqfindLongestUnique(const TQValueList < KTextEditor::CompletionEntry > &matches)
+TQString DocWordCompletionPluginView::findLongestUnique(const TQValueList < KTextEditor::CompletionEntry > &matches)
{
TQString partial = matches.front().text;
TQValueList < KTextEditor::CompletionEntry >::const_iterator i = matches.begin();
@@ -551,4 +551,4 @@ void DocWordCompletionConfigPage::defaults()
//END DocWordCompletionConfigPage
#include "docwordcompletion.moc"
-// kate: space-indent on; indent-width 2; tqreplace-tabs on; mixed-indent off;
+// kate: space-indent on; indent-width 2; replace-tabs on; mixed-indent off;
@@ -232,7 +232,7 @@ void DocWordCompletionPluginView::shellComplete()
// setup
KTextEditor::EditInterface * ei = KTextEditor::editInterface(m_view->document());
- // tqfind the word we are typing
+ // find the word we are typing
uint cline, ccol;
viewCursorInterface(m_view)->cursorPositionReal(&cline, &ccol);
@@ -261,7 +261,7 @@ void DocWordCompletionPluginView::complete( bool fw )
// setup
KTextEditor::EditInterface *ei = KTextEditor::editInterface( m_view->document() );
- // tqfind the word we are typing
+ // find the word we are typing
uint cline, ccol;
viewCursorInterface( m_view )->cursorPositionReal( &cline, &ccol );